@@ -1,7 +1,7 @@
 #! /bin/sh
 #
 # Copyright (c) 2004,  Theodore A. Roth
-# Copyright (c) 2005,2006,2007,2009  Anatoly Sokolov
+# Copyright (c) 2005,2006,2007,2008,2009  Anatoly Sokolov
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 #
-# $Id: gen-avr-lib-tree.sh,v 1.37.2.37 2009/12/03 18:38:59 arcanum Exp $
+# $Id: gen-avr-lib-tree.sh 2211 2011-02-14 14:04:25Z aboyapati $
 #
 
 # This is a script to automate the generation of the avr/lib/ tree. Since
@@ -41,82 +41,6 @@
 # the AUTHORS file in the current dir and the parent. After that, we complain
 # and fatal error out.
 
-top_dir="UNKNOWN"
-
-if test -e AUTHORS
-then
-	top_dir="$PWD"
-else
-	cd ..
-	if test -e AUTHORS
-	then
-		top_dir="$PWD"
-	fi
-fi
-
-if test $top_dir = "UNKNOWN"
-then
-	echo "Can't determine the top level source dir. Aborting."
-	exit 1
-fi
-
-test -d avr || mkdir avr
-test -d avr/lib || mkdir avr/lib
-
-cd avr || exit 1
-
-TMP_COPY_RIGHT_HDR="$PWD/tmp_copy_right_hdr"
-
-cat > ${TMP_COPY_RIGHT_HDR} <<EOF
-# Copyright (c) 2004,  Theodore A. Roth
-# Copyright (c) 2005,  Anatoly Sokolov
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are met:
-#
-# * Redistributions of source code must retain the above copyright
-#   notice, this list of conditions and the following disclaimer.
-# * Redistributions in binary form must reproduce the above copyright
-#   notice, this list of conditions and the following disclaimer in
-#   the documentation and/or other materials provided with the
-#   distribution.
-# * Neither the name of the copyright holders nor the names of
-#   contributors may be used to endorse or promote products derived
-#   from this software without specific prior written permission.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
-# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
-# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-# POSSIBILITY OF SUCH DAMAGE.
-#
-
-##
-## NOTE: This file was generated by the gen-avr-lib-tree.sh script found in
-## the devtools/ directory of the avr-libc source. If you find that this file
-## needs modification, please make the changes in the generator script. To
-## propagate the changes, be sure to run the generator script from the top
-## level directory of the source tree. (HINT: Your next build will proceed
-## much faster if you then re-run the bootstrap script.)
-##
-
-EOF
-
-# Create the avr/Makefile.am file.
-cat ${TMP_COPY_RIGHT_HDR} > Makefile.am
-cat >> Makefile.am << EOF
-SUBDIRS = lib
-EOF
-
-cd lib || exit 1
-
 # Define the special flags for special sub-targets.
 
 CFLAGS_SPACE="-mcall-prologues -Os"
@@ -178,6 +102,7 @@ attiny461:crttn461.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny461a:crttn461a.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny48:crttn48.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny84:crttn84.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny84a:crttn84a.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny85:crttn85.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny861:crttn861.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny861a:crttn861a.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
@@ -260,6 +185,7 @@ atmega169pa:crtm169pa.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega16hva:crtm16hva.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega16hva2:crtm16hva2.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega16hvb:crtm16hvb.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega16hvbrevb:crtm16hvbrevb.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega16m1:crtm16m1.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega16u4:crtm16u4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega32:crtm32.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
@@ -268,18 +194,23 @@ atmega324a:crtm324a.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega324p:crtm324p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega324pa:crtm324pa.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega325:crtm325.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega325a:crtm325a.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega325p:crtm325p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega3250:crtm3250.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega3250a:crtm3250a.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega3250p:crtm3250p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega328:crtm328.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega328p:crtm328p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega329:crtm329.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega329a:crtm329a.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega329p:crtm329p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega329pa:crtm329pa.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega3290:crtm3290.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega3290a:crtm3290a.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega3290p:crtm3290p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega32c1:crtm32c1.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega32hvb:crtm32hvb.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega32hvbrevb:crtm32hvbrevb.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega32m1:crtm32m1.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega32u4:crtm32u4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega32u6:crtm32u6.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
@@ -309,7 +240,8 @@ atmega128:crtm128.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega1280:crtm1280.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega1281:crtm1281.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega1284p:crtm1284p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
-atmega128rfa1:crtm128rfa1.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
+atmega128rfa1:crtm128rfa1.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+m3000:crtm3000.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 AVR51_DEV_INFO="\
@@ -329,13 +261,10 @@ atmega2561:crtm2561.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS}\
 "
 
 AVRXMEGA2_DEV_INFO="\
-atxmega32d4:crtx32d4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atxmega16a4:crtx16a4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
-atxmega16d4:crtx16d4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
-"
-
-AVRXMEGA3_DEV_INFO="\
-atxmega32a4:crtx32a4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
+atxmega16d4:crtx16d4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atxmega32a4:crtx32a4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atxmega32d4:crtx32d4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 AVRXMEGA4_DEV_INFO="\
@@ -344,7 +273,8 @@ atxmega64d3:crtx64d3.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS}\
 "
 
 AVRXMEGA5_DEV_INFO="\
-atxmega64a1:crtx64a1.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS}\
+atxmega64a1:crtx64a1.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS};\
+atxmega64a1u:crtx64a1u.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS}\
 "
 
 AVRXMEGA6_DEV_INFO="\
@@ -358,9 +288,20 @@ atxmega256d3:crtx256d3.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS}\
 "
 
 AVRXMEGA7_DEV_INFO="\
-atxmega128a1:crtx128a1.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS}\
+atxmega128a1:crtx128a1.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS};\
+atxmega128a1u:crtx128a1u.o:${DEV_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS}\
 "
 
+AVRTINY10_DEV_INFO="\
+attiny4:crttn4.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny5:crttn5.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny9:crttn9.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny10:crttn10.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny20:crttn20.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny40:crttn40.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
+"
+
+
 LIB_DEFS="-D__COMPILING_AVR_LIBC__"
 
 AVR_ARH_INFO="\
@@ -374,17 +315,41 @@ avr5:AVR5_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 avr51:AVR51_DEV_INFO:${LIB_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS};\
 avr6:AVR6_DEV_INFO:${LIB_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS};\
 avrxmega2:AVRXMEGA2_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
-avrxmega3:AVRXMEGA3_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 avrxmega4:AVRXMEGA4_DEV_INFO:${LIB_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS};\
 avrxmega5:AVRXMEGA5_DEV_INFO:${LIB_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS};\
 avrxmega6:AVRXMEGA6_DEV_INFO:${LIB_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS};\
-avrxmega7:AVRXMEGA7_DEV_INFO:${LIB_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS}\
+avrxmega7:AVRXMEGA7_DEV_INFO:${LIB_DEFS}:${CFLAGS_BIG_MEMORY}:${DEV_ASFLAGS};\
+avrtiny10:AVRTINY10_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 echo "Generating source directories:"
 
+top_dir="UNKNOWN"
+
+if test -e AUTHORS
+then
+	top_dir="$PWD"
+else
+	cd ..
+	if test -e AUTHORS
+	then
+		top_dir="$PWD"
+	fi
+fi
+
+if test $top_dir = "UNKNOWN"
+then
+	echo "Can't determine the top level source dir. Aborting."
+	exit 1
+fi
+
+test -d avr || mkdir avr
+test -d avr/lib || mkdir avr/lib
+
+cd avr/lib || exit 1
+
 IFS=';'
-ARH_SUBDIRS="SUBDIRS ="
+ARH_SUBDIRS=""
 
 for ath_lib in $AVR_ARH_INFO
 do
@@ -393,7 +358,7 @@ do
 	lib_defs=$(echo $ath_lib | cut -d ':' -f 3)
 	lib_cflags=$(echo $ath_lib | cut -d ':' -f 4)
 	lib_asflags=$(echo $ath_lib | cut -d ':' -f 5)
-	
+
 	install_dir=$arh
 	if [ $arh = avr2 ]
 	then
@@ -403,11 +368,9 @@ do
 	echo "  avr/lib/$arh/"
 
 	test -d $arh || mkdir $arh
+	cd $arh || exit 1
 
-	ARH_SUBDIRS="$ARH_SUBDIRS $arh"
-
-
-	DEV_SUBDIRS="SUBDIRS ="
+	DEV_SUBDIRS=""
 
 	eval DEV_INFO=\"\$\{$dev_info\}\"
 
@@ -418,95 +381,67 @@ do
 		crt_defs=$(echo $dev_crt | cut -d ':' -f 3)
 		crt_cflags=$(echo $dev_crt | cut -d ':' -f 4)
 		crt_asflags=$(echo $dev_crt | cut -d ':' -f 5)
-		
+
 		echo "  avr/lib/$arh/$dev"
-		
-		test -d $arh/$dev || mkdir $arh/$dev
+
+		test -d $dev || mkdir $dev
+
+		cat $top_dir/devtools/Device.am > $dev/Makefile.am
+
+		sed -e "s/<<dev>>/$dev/g" \
+		    -e "s/<<crt>>/$crt/g" \
+		    -e "s/<<crt_defs>>/$crt_defs/g" \
+		    -e "s/<<crt_cflags>>/$crt_cflags/g" \
+		    -e "s/<<crt_asflags>>/$crt_asflags/g"  \
+		    -e "s/<<install_dir>>/$install_dir/g" $dev/Makefile.am \
+		    > $dev/tempfile && mv -f $dev/tempfile $dev/Makefile.am
 
 		DEV_SUBDIRS="$DEV_SUBDIRS $dev"
-
-		cat ${TMP_COPY_RIGHT_HDR} > $arh/$dev/Makefile.am
-		cat >> $arh/$dev/Makefile.am <<EOF
-
-AVR_TARGET          = $dev
-AVR_TARGET_CRT      = $crt
-AVR_TARGET_DEFS     = $crt_defs
-AVR_TARGET_CFLAGS   = $crt_cflags
-AVR_TARGET_ASFLAGS  = $crt_asflags
-AVR_INSTALL_DIR     = $install_dir
-
-VPATH = \$(top_srcdir)/crt1:\$(top_srcdir)/libc/stdlib:\$(top_srcdir)/libc/pmstring:\$(top_srcdir)/libc/string:\$(top_srcdir)/libc/misc:\$(top_srcdir)/libc/stdio:\$(top_srcdir)/libm/fplib
-
-if HAS_$dev
-
-# NOTE: Automake will be performing the following include, not GNU Make.
-# Automake will also be scanning the included file.
-
-include \$(top_srcdir)/AvrCommon.am
-
-else
-
-echo all distdir install installdirs clean distclean uninstall check:
-
-endif
-
-EOF
-
 	done
+
+	cat $top_dir/devtools/Architecture.am > Makefile.am
+
+	sed -e "s/<<dev_subdirs>>/$DEV_SUBDIRS/g" \
+	    -e "s/<<arh>>/$arh/g" \
+	    -e "s/<<lib_defs>>/$lib_defs/g" \
+	    -e "s/<<lib_cflags>>/$lib_cflags/g" \
+	    -e "s/<<lib_asflags>>/$lib_asflags/g" \
+	    -e "s/<<install_dir>>/$install_dir/g" Makefile.am \
+	    > tempfile && mv -f tempfile Makefile.am
+
+	# Find the first and the last lines of <<dev>> block.
+	n1=`grep '^if[[:blank:]]+HAS_<<dev>>' -En Makefile.am	\
+	    | cut -d ':' -f 1`
+	n2=`grep '^endif[[:blank:]]+#[[:blank:]]*<<dev>>' -En Makefile.am \
+	    | cut -d ':' -f 1`
+
+	# Before the <<dev>> block.
+	head -n $(($n1 - 1)) Makefile.am > tempfile
+
+	# Duplicate the <<dev>> block and substitute.
+	for dev_crt in $DEV_INFO ; do
+		dev=`echo $dev_crt | cut -d ':' -f 1`
+		tail -n +$n1 Makefile.am	\
+		    | head -n $(($n2 - $n1 + 1))	\
+		    | sed -e "s/<<dev>>/$dev/g" >> tempfile
+	done
+
+	# After the <<dev>> block.
+	tail -n +$(($n2 + 1)) Makefile.am >> tempfile
 	
+	# Result.
+	mv -f tempfile Makefile.am
 
-	cat ${TMP_COPY_RIGHT_HDR} > $arh/Makefile.am
-	printf "$DEV_SUBDIRS" >> $arh/Makefile.am
-	echo >> $arh/Makefile.am
-	cat >> $arh/Makefile.am <<EOF
-
-AVR_TARGET          = $arh
-AVR_TARGET_CRT      = $crt
-AVR_TARGET_DEFS     = $lib_defs
-AVR_TARGET_CFLAGS   = $lib_cflags
-AVR_TARGET_ASFLAGS  = $lib_asflags
-AVR_INSTALL_DIR     = $install_dir
-
-VPATH = \$(top_srcdir)/crt1:\$(top_srcdir)/libc/stdlib:\$(top_srcdir)/libc/pmstring:\$(top_srcdir)/libc/string:\$(top_srcdir)/libc/misc:\$(top_srcdir)/libc/stdio:\$(top_srcdir)/libm/fplib
-
-if HAS_$arh
-
-AVRLIB_DEVLIST =
-EOF
-
-	for dev_crt in $DEV_INFO
-	do
-		dev=$(echo $dev_crt | cut -d ':' -f 1)
-		cat >> $arh/Makefile.am <<EOF
-if HAS_$dev
-  AVRLIB_DEVLIST += $dev
-endif	# $dev
-EOF
-	done
-
-	cat >> $arh/Makefile.am <<EOF
-
-# NOTE: Automake will be performing the following include, not GNU Make.
-# Automake will also be scanning the included file.
-
-include \$(top_srcdir)/AvrCommonLibC.am
-
-else
-
-echo all distdir install installdirs clean distclean uninstall check:
-
-endif
-
-EOF
-
-	#printf  $DEV_SUBDIRS
-	#echo 
+	ARH_SUBDIRS="$ARH_SUBDIRS $arh"
 
+	cd ..
 done
 
-cat ${TMP_COPY_RIGHT_HDR} > Makefile.am
-printf "$ARH_SUBDIRS" >> Makefile.am
-echo >> Makefile.am
+cat $top_dir/devtools/Lib.am > Makefile.am
 
-rm -f ${TMP_COPY_RIGHT_HDR}
+sed -e "s/<<arh_subdirs>>/$ARH_SUBDIRS/g" Makefile.am \
+    > tempfile && mv -f tempfile Makefile.am
 
+cd ..
+
+cat $top_dir/devtools/Avr.am > Makefile.am
