@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2003, 2004, 2005, 2006, 2007  Eric B. Weddington
+/* Copyright (c) 2002,2003,2004,2005,2006,2007,2008,2009  Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: boot.h,v 1.27.2.5 2009/04/25 21:29:10 arcanum Exp $ */
+/* $Id: boot.h 2102 2010-03-16 22:52:39Z joerg_wunsch $ */
 
 #ifndef _AVR_BOOT_H_
 #define _AVR_BOOT_H_    1
@@ -211,9 +211,9 @@
         "clr  r1\n\t"                            \
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
-          "r" ((uint8_t)__BOOT_PAGE_FILL),       \
-          "z" ((uint16_t)address),               \
-          "r" ((uint16_t)data)                   \
+          "r" ((uint8_t)(__BOOT_PAGE_FILL)),     \
+          "z" ((uint16_t)(address)),             \
+          "r" ((uint16_t)(data))                 \
         : "r0"                                   \
     );                                           \
 }))
@@ -230,9 +230,9 @@
         "clr  r1\n\t"                            \
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
-          "r" ((uint8_t)__BOOT_PAGE_FILL),       \
-          "z" ((uint16_t)address),               \
-          "r" ((uint16_t)data)                   \
+          "r" ((uint8_t)(__BOOT_PAGE_FILL)),     \
+          "z" ((uint16_t)(address)),             \
+          "r" ((uint16_t)(data))                 \
         : "r0"                                   \
     );                                           \
 }))
@@ -250,9 +250,9 @@
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
           "i" (_SFR_MEM_ADDR(RAMPZ)),            \
-          "r" ((uint8_t)__BOOT_PAGE_FILL),       \
-          "r" ((uint32_t)address),               \
-          "r" ((uint16_t)data)                   \
+          "r" ((uint8_t)(__BOOT_PAGE_FILL)),     \
+          "r" ((uint32_t)(address)),             \
+          "r" ((uint16_t)(data))                 \
         : "r0", "r30", "r31"                     \
     );                                           \
 }))
@@ -265,8 +265,8 @@
         "spm\n\t"                                \
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
-          "r" ((uint8_t)__BOOT_PAGE_ERASE),      \
-          "z" ((uint16_t)address)                \
+          "r" ((uint8_t)(__BOOT_PAGE_ERASE)),    \
+          "z" ((uint16_t)(address))              \
     );                                           \
 }))
 
@@ -280,8 +280,8 @@
         "nop\n\t"                                \
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
-          "r" ((uint8_t)__BOOT_PAGE_ERASE),      \
-          "z" ((uint16_t)address)                \
+          "r" ((uint8_t)(__BOOT_PAGE_ERASE)),    \
+          "z" ((uint16_t)(address))              \
     );                                           \
 }))
 
@@ -296,8 +296,8 @@
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
           "i" (_SFR_MEM_ADDR(RAMPZ)),            \
-          "r" ((uint8_t)__BOOT_PAGE_ERASE),      \
-          "r" ((uint32_t)address)                \
+          "r" ((uint8_t)(__BOOT_PAGE_ERASE)),    \
+          "r" ((uint32_t)(address))              \
         : "r30", "r31"                           \
     );                                           \
 }))
@@ -310,8 +310,8 @@
         "spm\n\t"                                \
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
-          "r" ((uint8_t)__BOOT_PAGE_WRITE),      \
-          "z" ((uint16_t)address)                \
+          "r" ((uint8_t)(__BOOT_PAGE_WRITE)),    \
+          "z" ((uint16_t)(address))              \
     );                                           \
 }))
 
@@ -325,8 +325,8 @@
         "nop\n\t"                                \
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
-          "r" ((uint8_t)__BOOT_PAGE_WRITE),      \
-          "z" ((uint16_t)address)                \
+          "r" ((uint8_t)(__BOOT_PAGE_WRITE)),    \
+          "z" ((uint16_t)(address))              \
     );                                           \
 }))
 
@@ -341,8 +341,8 @@
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
           "i" (_SFR_MEM_ADDR(RAMPZ)),            \
-          "r" ((uint8_t)__BOOT_PAGE_WRITE),      \
-          "r" ((uint32_t)address)                \
+          "r" ((uint8_t)(__BOOT_PAGE_WRITE)),    \
+          "r" ((uint32_t)(address))              \
         : "r30", "r31"                           \
     );                                           \
 }))
@@ -355,7 +355,7 @@
         "spm\n\t"                                \
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
-          "r" ((uint8_t)__BOOT_RWW_ENABLE)       \
+          "r" ((uint8_t)(__BOOT_RWW_ENABLE))     \
     );                                           \
 }))
 
@@ -369,7 +369,7 @@
         "nop\n\t"                                \
         :                                        \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),        \
-          "r" ((uint8_t)__BOOT_RWW_ENABLE)       \
+          "r" ((uint8_t)(__BOOT_RWW_ENABLE))     \
     );                                           \
 }))
 
@@ -402,7 +402,7 @@
         "spm\n\t"                                          \
         :                                                  \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),                  \
-          "r" ((uint8_t)__BOOT_LOCK_BITS_SET),             \
+          "r" ((uint8_t)(__BOOT_LOCK_BITS_SET)),           \
           "r" (value)                                      \
         : "r0", "r30", "r31"                               \
     );                                                     \
@@ -422,7 +422,7 @@
         "nop\n\t"                                          \
         :                                                  \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),                  \
-          "r" ((uint8_t)__BOOT_LOCK_BITS_SET),             \
+          "r" ((uint8_t)(__BOOT_LOCK_BITS_SET)),           \
           "r" (value)                                      \
         : "r0", "r30", "r31"                               \
     );                                                     \
@@ -489,8 +489,8 @@
         "lpm %0, Z\n\t"                                    \
         : "=r" (__result)                                  \
         : "i" (_SFR_MEM_ADDR(__SPM_REG)),                  \
-          "r" ((uint8_t)__BOOT_LOCK_BITS_SET),             \
-          "z" ((uint16_t)address)                          \
+          "r" ((uint8_t)(__BOOT_LOCK_BITS_SET)),           \
+          "z" ((uint16_t)(address))                        \
     );                                                     \
     __result;                                              \
 }))
@@ -509,19 +509,18 @@
 #define __BOOT_SIGROW_READ (_BV(__SPM_ENABLE) | _BV(SIGRD))
 
 #define boot_signature_byte_get(addr) \
-(__extension__({		      \
-      uint16_t __addr16 = (uint16_t)(addr);	\
-      uint8_t __result;				\
-      __asm__ __volatile__			\
-      (						\
-	"sts %1, %2\n\t"			\
-	"lpm %0, Z" "\n\t"			\
-	: "=r" (__result)			\
-	: "i" (_SFR_MEM_ADDR(__SPM_REG)),	\
-	  "r" ((uint8_t) __BOOT_SIGROW_READ),	\
-	  "z" (__addr16)			\
-      );					\
-      __result;					\
+(__extension__({                      \
+      uint8_t __result;                         \
+      __asm__ __volatile__                      \
+      (                                         \
+        "sts %1, %2\n\t"                        \
+        "lpm %0, Z" "\n\t"                      \
+        : "=r" (__result)                       \
+        : "i" (_SFR_MEM_ADDR(__SPM_REG)),       \
+          "r" ((uint8_t)(__BOOT_SIGROW_READ)),  \
+          "z" ((uint16_t)(addr))                \
+      );                                        \
+      __result;                                 \
 }))
 
 /** \ingroup avr_boot
