@@ -1,4 +1,4 @@
-/* Copyright (c) 2003, Keith Gudger
+/* Copyright (c) 2003,2005 Keith Gudger
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,6 +28,8 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
+/* $Id: io43u35x.h 1873 2009-02-11 17:53:39Z arcanum $ */
+
 /* avr/io43u35x.h - definitions for AT43USB35x */
 
 #ifndef _AVR_IO43U35X_H_
@@ -51,6 +53,7 @@
 #ifndef __ASSEMBLER__
 #define ADC 	_SFR_IO16(0x02)
 #endif
+#define ADCW  	_SFR_IO16(0x02)
 #define ADCL	_SFR_IO8(0x02)
 #define ADCH	_SFR_IO8(0x03)
 
@@ -126,7 +129,7 @@
 /* Data Register, Port A */
 #define PORTA	_SFR_IO8(0x1B)
 
-/* 0x1C..0x1F EEPROM */
+/* 0x1C..0x1F reserved */
 
 /* Watchdog Timer Control Register */
 #define WDTCR	_SFR_IO8(0x21)
@@ -183,6 +186,7 @@
 #define SIG_INTERRUPT0		_VECTOR(1)  /* suspend/resume */
 #define SIG_INTERRUPT1		_VECTOR(2)
 #define SIG_TIMER1_CAPT1	_VECTOR(3)
+#define SIG_INPUT_CAPTURE1	_VECTOR(3)
 #define SIG_OUTPUT_COMPARE1A		_VECTOR(4)
 #define SIG_OUTPUT_COMPARE1B		_VECTOR(5)
 #define SIG_OVERFLOW1		_VECTOR(6)
@@ -417,7 +421,7 @@
 
 /* Constants */
 #define    RAMEND   0x045F     /*Last On-Chip SRAM Location*/
-#define    XRAMEND  0x045F
+#define    XRAMEND  RAMEND
 #define    E2END    0x0000
 #define    FLASHEND 0x5FFF
 
