@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io4433.h,v 1.9 2005/10/30 22:11:23 joerg_wunsch Exp $ */
+/* $Id: io4433.h 2225 2011-03-02 16:27:26Z arcanum $ */
 
 /* avr/io4433.h - definitions for AT90S4433 */
 
@@ -180,54 +180,67 @@
 /* Interrupt vectors */
 
 /* External Interrupt 0 */
+#define INT0_vect_num		1
 #define INT0_vect			_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt 1 */
+#define INT1_vect_num		2
 #define INT1_vect			_VECTOR(2)
 #define SIG_INTERRUPT1			_VECTOR(2)
 
 /* Timer/Counter Capture Event */
+#define TIMER1_CAPT_vect_num	3
 #define TIMER1_CAPT_vect		_VECTOR(3)
 #define SIG_INPUT_CAPTURE1		_VECTOR(3)
 
 /* Timer/Counter1 Compare Match */
+#define TIMER1_COMP_vect_num	4
 #define TIMER1_COMP_vect		_VECTOR(4)
 #define SIG_OUTPUT_COMPARE1A		_VECTOR(4)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		5
 #define TIMER1_OVF_vect			_VECTOR(5)
 #define SIG_OVERFLOW1			_VECTOR(5)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		6
 #define TIMER0_OVF_vect			_VECTOR(6)
 #define SIG_OVERFLOW0			_VECTOR(6)
 
 /* Serial Transfer Complete */
+#define SPI_STC_vect_num		7
 #define SPI_STC_vect			_VECTOR(7)
 #define SIG_SPI				_VECTOR(7)
 
 /* UART, Rx Complete */
+#define UART_RX_vect_num		8
 #define UART_RX_vect			_VECTOR(8)
 #define SIG_UART_RECV			_VECTOR(8)
 
 /* UART Data Register Empty */
+#define UART_UDRE_vect_num		9
 #define UART_UDRE_vect			_VECTOR(9)
 #define SIG_UART_DATA			_VECTOR(9)
 
 /* UART, Tx Complete */
+#define UART_TX_vect_num		10
 #define UART_TX_vect			_VECTOR(10)
 #define SIG_UART_TRANS			_VECTOR(10)
 
 /* ADC Conversion Complete */
+#define ADC_vect_num		11
 #define ADC_vect			_VECTOR(11)
 #define SIG_ADC				_VECTOR(11)
 
 /* EEPROM Ready */
+#define EE_RDY_vect_num		12
 #define EE_RDY_vect			_VECTOR(12)
 #define SIG_EEPROM_READY		_VECTOR(12)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		13
 #define ANA_COMP_vect			_VECTOR(13)
 #define SIG_COMPARATOR			_VECTOR(13)
 
@@ -440,9 +453,34 @@
 #define    EERE      0
 
 /* Constants */
-#define    RAMEND   0xDF    /*Last On-Chip SRAM location*/
-#define    XRAMEND  0xDF
-#define    E2END    0xFF
-#define    FLASHEND 0xFFF
+#define RAMEND     0xDF    /*Last On-Chip SRAM location*/
+#define XRAMEND    RAMEND
+#define E2END      0xFF
+#define E2PAGESIZE 0
+#define FLASHEND   0xFFF
+
+
+/* Fuses */
+#define FUSE_MEMORY_SIZE 1
+
+/* Low Fuse Byte */
+#define FUSE_CKSEL0 (unsigned char)~_BV(0)
+#define FUSE_CKSEL1 (unsigned char)~_BV(1)
+#define FUSE_CKSEL2 (unsigned char)~_BV(2)
+#define FUSE_BODEN (unsigned char)~_BV(3)
+#define FUSE_BODLEVEL (unsigned char)~_BV(4)
+#define FUSE_SPIEN (unsigned char)~_BV(5)
+#define LFUSE_DEFAULT (0xFF)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+
+
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x92
+#define SIGNATURE_2 0x03
+
 
 #endif /* _AVR_IO4433_H_ */
