@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io4434.h 1873 2009-02-11 17:53:39Z arcanum $ */
+/* $Id: io4434.h 2225 2011-03-02 16:27:26Z arcanum $ */
 
 /* avr/io4434.h - definitions for AT90S4434 */
 
@@ -205,66 +205,82 @@
 /* Interrupt vectors */
 
 /* External Interrupt 0 */
+#define INT0_vect_num		1
 #define INT0_vect			_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt 1 */
+#define INT1_vect_num		2
 #define INT1_vect			_VECTOR(2)
 #define SIG_INTERRUPT1			_VECTOR(2)
 
 /* Timer/Counter2 Compare Match */
+#define TIMER2_COMP_vect_num	3
 #define TIMER2_COMP_vect		_VECTOR(3)
 #define SIG_OUTPUT_COMPARE2		_VECTOR(3)
 
 /* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect_num		4
 #define TIMER2_OVF_vect			_VECTOR(4)
 #define SIG_OVERFLOW2			_VECTOR(4)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	5
 #define TIMER1_CAPT_vect		_VECTOR(5)
 #define SIG_INPUT_CAPTURE1		_VECTOR(5)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num	6
 #define TIMER1_COMPA_vect		_VECTOR(6)
 #define SIG_OUTPUT_COMPARE1A		_VECTOR(6)
 
 /* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect_num	7
 #define TIMER1_COMPB_vect		_VECTOR(7)
 #define SIG_OUTPUT_COMPARE1B		_VECTOR(7)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		8
 #define TIMER1_OVF_vect			_VECTOR(8)
 #define SIG_OVERFLOW1			_VECTOR(8)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		9
 #define TIMER0_OVF_vect			_VECTOR(9)
 #define SIG_OVERFLOW0			_VECTOR(9)
 
 /* SPI Serial Transfer Complete */
+#define SPI_STC_vect_num		10
 #define SPI_STC_vect			_VECTOR(10)
 #define SIG_SPI				_VECTOR(10)
 
 /* UART, RX Complete */
+#define UART_RX_vect_num		11
 #define UART_RX_vect			_VECTOR(11)
 #define SIG_UART_RECV			_VECTOR(11)
 
 /* UART Data Register Empty */
+#define UART_UDRE_vect_num		12
 #define UART_UDRE_vect			_VECTOR(12)
 #define SIG_UART_DATA			_VECTOR(12)
 
 /* UART, TX Complete */
+#define UART_TX_vect_num		13
 #define UART_TX_vect			_VECTOR(13)
 #define SIG_UART_TRANS			_VECTOR(13)
 
 /* ADC Conversion Complete */
+#define ADC_vect_num		14
 #define ADC_vect			_VECTOR(14)
 #define SIG_ADC				_VECTOR(14)
 
 /* EEPROM Ready */
+#define EE_RDY_vect_num		15
 #define EE_RDY_vect			_VECTOR(15)
 #define SIG_EEPROM_READY		_VECTOR(15)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		16
 #define ANA_COMP_vect			_VECTOR(16)
 #define SIG_COMPARATOR			_VECTOR(16)
 
