@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: io90pwm2b.h,v 1.1.2.2 2007/10/19 23:16:30 arcanum Exp $ */
+/* $Id: io90pwm2b.h 2225 2011-03-02 16:27:26Z arcanum $ */
 
 /* avr/io90pwm2b.h - definitions for AT90PWM2B */
 
@@ -82,10 +82,34 @@
 #define PORTB7 7
       
 #define PINC _SFR_IO8(0x06)
+#define PINC0 0
+#define PINC1 1
+#define PINC2 2
+#define PINC3 3
+#define PINC4 4
+#define PINC5 5
+#define PINC6 6
+#define PINC7 7
 
 #define DDRC _SFR_IO8(0x07)
+#define DDC0 0
+#define DDC1 1
+#define DDC2 2
+#define DDC3 3
+#define DDC4 4
+#define DDC5 5
+#define DDC6 6
+#define DDC7 7
 
 #define PORTC _SFR_IO8(0x08)
+#define PORTC0 0
+#define PORTC1 1
+#define PORTC2 2
+#define PORTC3 3
+#define PORTC4 4
+#define PORTC5 5
+#define PORTC6 6
+#define PORTC7 7
 
 #define PIND _SFR_IO8(0x09)
 #define PIND0 0
@@ -177,11 +201,13 @@
 #define INTF0 0
 #define INTF1 1
 #define INTF2 2
+#define INTF3 3
 
 #define EIMSK _SFR_IO8(0x1D)
 #define INT0 0
 #define INT1 1
 #define INT2 2
+#define INT3 3
 
 #define GPIOR0 _SFR_IO8(0x1E)
 #define GPIOR00 0
@@ -211,6 +237,8 @@
 #define EEDR6 6
 #define EEDR7 7
 
+#define EEAR _SFR_IO16(0x21)
+
 #define EEARL _SFR_IO8(0x21)
 #define EEARL0 0
 #define EEARL1 1
@@ -260,24 +288,33 @@
 #define TCNT0_7 7
 
 #define OCR0A _SFR_IO8(0x27)
-#define OCR0_0 0
-#define OCR0_1 1
-#define OCR0_2 2
-#define OCR0_3 3
-#define OCR0_4 4
-#define OCR0_5 5
-#define OCR0_6 6
-#define OCR0_7 7
+#define OCR0A_0 0
+#define OCR0A_1 1
+#define OCR0A_2 2
+#define OCR0A_3 3
+#define OCR0A_4 4
+#define OCR0A_5 5
+#define OCR0A_6 6
+#define OCR0A_7 7
 
 #define OCR0B _SFR_IO8(0x28)
-#define OCR0_0 0
-#define OCR0_1 1
-#define OCR0_2 2
-#define OCR0_3 3
-#define OCR0_4 4
-#define OCR0_5 5
-#define OCR0_6 6
-#define OCR0_7 7
+#define OCR0B_0 0
+#define OCR0B_1 1
+#define OCR0B_2 2
+#define OCR0B_3 3
+#define OCR0B_4 4
+#define OCR0B_5 5
+#define OCR0B_6 6
+#define OCR0B_7 7
+
+#define OCR0_0 0    /* Deprecated */
+#define OCR0_1 1    /* Deprecated */
+#define OCR0_2 2    /* Deprecated */
+#define OCR0_3 3    /* Deprecated */
+#define OCR0_4 4    /* Deprecated */
+#define OCR0_5 5    /* Deprecated */
+#define OCR0_6 6    /* Deprecated */
+#define OCR0_7 7    /* Deprecated */
 
 #define PLLCSR _SFR_IO8(0x29)
 #define PLOCK 0
@@ -349,7 +386,7 @@
 #define WDP0 0
 #define WDP1 1
 #define WDP2 2
-#define WDE3 3
+#define WDE 3
 #define WDCE 4
 #define WDP3 5
 #define WDIE 6
@@ -388,6 +425,8 @@
 #define ISC11 3
 #define ISC20 4
 #define ISC21 5
+#define ISC30 6
+#define ISC31 7
 
 #define TIMSK0 _SFR_MEM8(0x6E)
 #define TOIE0 0
@@ -401,8 +440,25 @@
 #define ICIE1 5
 
 #define AMP0CSR _SFR_MEM8(0x76)
+#define AMP0TS0 0
+#define AMP0TS1 1
+#define AMP0G0 4
+#define AMP0G1 5
+#define AMP0IS 6
+#define AMP0EN 7
 
 #define AMP1CSR _SFR_MEM8(0x77)
+#define AMP1TS0 0
+#define AMP1TS1 1
+#define AMP1G0 4
+#define AMP1G1 5
+#define AMP1IS 6
+#define AMP1EN 7
+
+#ifndef __ASSEMBLER__
+#define ADC     _SFR_MEM16(0x78)
+#endif
+#define ADCW    _SFR_MEM16(0x78)
 
 #define ADCL _SFR_MEM8(0x78)
 #define ADCL0 0
@@ -414,6 +470,16 @@
 #define ADCL6 6
 #define ADCL7 7
 
+#define ADCH _SFR_MEM8(0x79)
+#define ADCH0 0
+#define ADCH1 1
+#define ADCH2 2
+#define ADCH3 3
+#define ADCH4 4
+#define ADCH5 5
+#define ADCH6 6
+#define ADCH7 7
+
 #define ADCSRA _SFR_MEM8(0x7A)
 #define ADPS0 0
 #define ADPS1 1
@@ -502,7 +568,7 @@
 #define TCNT1H6 6
 #define TCNT1H7 7
 
-#define ICR1 _SFR_MEM8(0x86)
+#define ICR1 _SFR_MEM16(0x86)
 
 #define ICR1L _SFR_MEM8(0x86)
 #define ICR1L0 0
@@ -585,8 +651,20 @@
 #define PSEIE0 5
 
 #define PIFR1 _SFR_MEM8(0xA2)
+#define PEOP1 0
+#define PRN10 1
+#define PRN11 2
+#define PEV1A 3
+#define PEV1B 4
+#define PSEI1 5
+#define POAC1A 6
+#define POAC1B 7
 
 #define PIM1 _SFR_MEM8(0xA3)
+#define PEOPE1 0
+#define PEVE1A 3
+#define PEVE1B 4
+#define PSEIE1 5
 
 #define PIFR2 _SFR_MEM8(0xA4)
 #define PEOP2 0
@@ -915,44 +993,144 @@
 #define PCST0 7
 
 #define PSOC1 _SFR_MEM8(0xE0)
+#define POEN1A 0
+#define POEN1B 2
+#define PSYNC1_0 4
+#define PSYNC1_1 5
 
 #define OCR1SA _SFR_MEM16(0xE2)
 
 #define OCR1SAL _SFR_MEM8(0xE2)
+#define OCR1SA_0 0
+#define OCR1SA_1 1
+#define OCR1SA_2 2
+#define OCR1SA_3 3
+#define OCR1SA_4 4
+#define OCR1SA_5 5
+#define OCR1SA_6 6
+#define OCR1SA_7 7
 
 #define OCR1SAH _SFR_MEM8(0xE3)
+#define OCR1SA_8 0
+#define OCR1SA_9 1
+#define OCR1SA_10 2
+#define OCR1SA_11 3
 
 #define OCR1RA _SFR_MEM16(0xE4)
 
 #define OCR1RAL _SFR_MEM8(0xE4)
+#define OCR1RA_0 0
+#define OCR1RA_1 1
+#define OCR1RA_2 2
+#define OCR1RA_3 3
+#define OCR1RA_4 4
+#define OCR1RA_5 5
+#define OCR1RA_6 6
+#define OCR1RA_7 7
 
 #define OCR1RAH _SFR_MEM8(0xE5)
+#define OCR1RA_8 0
+#define OCR1RA_9 1
+#define OCR1RA_10 2
+#define OCR1RA_11 3
 
 #define OCR1SB _SFR_MEM16(0xE6)
 
 #define OCR1SBL _SFR_MEM8(0xE6)
+#define OCR1SB_0 0
+#define OCR1SB_1 1
+#define OCR1SB_2 2
+#define OCR1SB_3 3
+#define OCR1SB_4 4
+#define OCR1SB_5 5
+#define OCR1SB_6 6
+#define OCR1SB_7 7
 
 #define OCR1SBH _SFR_MEM8(0xE7)
+#define OCR1SB_8 0
+#define OCR1SB_9 1
+#define OCR1SB_10 2
+#define OCR1SB_11 3
 
 #define OCR1RB _SFR_MEM16(0xE8)
 
 #define OCR1RBL _SFR_MEM8(0xE8)
+#define OCR1RB_0 0
+#define OCR1RB_1 1
+#define OCR1RB_2 2
+#define OCR1RB_3 3
+#define OCR1RB_4 4
+#define OCR1RB_5 5
+#define OCR1RB_6 6
+#define OCR1RB_7 7
 
 #define OCR1RBH _SFR_MEM8(0xE9)
+#define OCR1RB_8 0
+#define OCR1RB_9 1
+#define OCR1RB_10 2
+#define OCR1RB_11 3
+#define OCR1RB_12 4
+#define OCR1RB_13 5
+#define OCR1RB_14 6
+#define OCR1RB_15 7
 
 #define PCNF1 _SFR_MEM8(0xEA)
+#define PCLKSEL1 1
+#define POP1 2
+#define PMODE10 3
+#define PMODE11 4
+#define PLOCK1 5
+#define PALOCK1 6
+#define PFIFTY1 7
 
 #define PCTL1 _SFR_MEM8(0xEB)
+#define PRUN1 0
+#define PCCYC1 1
+#define PARUN1 2
+#define PAOC1A 3
+#define PAOC1B 4
+#define PBFM1 5
+#define PPRE10 6
+#define PPRE11 7
 
 #define PFRC1A _SFR_MEM8(0xEC)
+#define PRFM1A0 0
+#define PRFM1A1 1
+#define PRFM1A2 2
+#define PRFM1A3 3
+#define PFLTE1A 4
+#define PELEV1A 5
+#define PISEL1A 6
+#define PCAE1A 7
 
 #define PFRC1B _SFR_MEM8(0xED)
+#define PRFM1B0 0
+#define PRFM1B1 1
+#define PRFM1B2 2
+#define PRFM1B3 3
+#define PFLTE1B 4
+#define PELEV1B 5
+#define PISEL1B 6
+#define PCAE1B 7
 
 #define PICR1 _SFR_MEM16(0xEE)
 
 #define PICR1L _SFR_MEM8(0xEE)
+#define PICR1_0 0
+#define PICR1_1 1
+#define PICR1_2 2
+#define PICR1_3 3
+#define PICR1_4 4
+#define PICR1_5 5
+#define PICR1_6 6
+#define PICR1_7 7
 
 #define PICR1H _SFR_MEM8(0xEF)
+#define PICR1_8 0
+#define PICR1_9 1
+#define PICR1_10 2
+#define PICR1_11 3
+#define PCST1 7
 
 #define PSOC2 _SFR_MEM8(0xF0)
 #define POEN2A 0
@@ -999,7 +1177,8 @@
 #define OCR2RA_1 1
 #define OCR2RA_2 2
 #define OCR2RA_3 3
-#define OCR2RA_4 4#define OCR2RA_5 5
+#define OCR2RA_4 4
+#define OCR2RA_5 5
 #define OCR2RA_6 6
 #define OCR2RA_7 7
 
@@ -1112,36 +1291,95 @@
 
 /* Interrupt Vectors */
 /* Interrupt vector 0 is the reset vector. */
+
+#define PSC2_CAPT_vect_num  1
 #define PSC2_CAPT_vect      _VECTOR(1)   /* PSC2 Capture Event */
+
+#define PSC2_EC_vect_num    2
 #define PSC2_EC_vect        _VECTOR(2)   /* PSC2 End Cycle */
+
+#define PSC1_CAPT_vect_num  3
 #define PSC1_CAPT_vect      _VECTOR(3)   /* PSC1 Capture Event */
+
+#define PSC1_EC_vect_num    4
 #define PSC1_EC_vect        _VECTOR(4)   /* PSC1 End Cycle */
+
+#define PSC0_CAPT_vect_num  5
 #define PSC0_CAPT_vect      _VECTOR(5)   /* PSC0 Capture Event */
+
+#define PSC0_EC_vect_num    6
 #define PSC0_EC_vect        _VECTOR(6)   /* PSC0 End Cycle */
+
+#define ANALOG_COMP_0_vect_num  7
 #define ANALOG_COMP_0_vect  _VECTOR(7)   /* Analog Comparator 0 */
+
+#define ANALOG_COMP_1_vect_num  8
 #define ANALOG_COMP_1_vect  _VECTOR(8)   /* Analog Comparator 1 */
+
+#define ANALOG_COMP_2_vect_num 9
 #define ANALOG_COMP_2_vect  _VECTOR(9)   /* Analog Comparator 2 */
+
+#define INT0_vect_num       10
 #define INT0_vect           _VECTOR(10)  /* External Interrupt Request 0 */
+
+#define TIMER1_CAPT_vect_num 11
 #define TIMER1_CAPT_vect    _VECTOR(11)  /* Timer/Counter1 Capture Event */
+
+#define TIMER1_COMPA_vect_num 12
 #define TIMER1_COMPA_vect   _VECTOR(12)  /* Timer/Counter1 Compare Match A */
+
+#define TIMER1_COMPB_vect_num 13
 #define TIMER1_COMPB_vect   _VECTOR(13)  /* Timer/Counter Compare Match B */
+
 /* Vector 14, Reserved */
+
+#define TIMER1_OVF_vect_num 15
 #define TIMER1_OVF_vect     _VECTOR(15)  /* Timer/Counter1 Overflow */
-#define TIMER0_COMP A_vect  _VECTOR(16)  /* Timer/Counter0 Compare Match A */
+
+#define TIMER0_COMPA_vect_num 16
+#define TIMER0_COMPA_vect   _VECTOR(16)  /* Timer/Counter0 Compare Match A */
+
+#define TIMER0_OVF_vect_num 17
 #define TIMER0_OVF_vect     _VECTOR(17)  /* Timer/Counter0 Overflow */
+
+#define ADC_vect_num        18
 #define ADC_vect            _VECTOR(18)  /* ADC Conversion Complete */
+
+#define INT1_vect_num       19
 #define INT1_vect           _VECTOR(19)  /* External Interrupt Request 1 */
+
+#define SPI_STC_vect_num    20
 #define SPI_STC_vect        _VECTOR(20)  /* SPI Serial Transfer Complete */
+
+#define USART_RX_vect_num   21
 #define USART_RX_vect       _VECTOR(21)  /* USART, Rx Complete */
+
+#define USART_UDRE_vect_num  22
 #define USART_UDRE_vect     _VECTOR(22)  /* USART Data Register Empty */
+
+#define USART_TX_vect_num   23
 #define USART_TX_vect       _VECTOR(23)  /* USART, Tx Complete */
+
+#define INT2_vect_num       24
 #define INT2_vect           _VECTOR(24)  /* External Interrupt Request 2 */
+
+#define WDT_vect_num        25
 #define WDT_vect            _VECTOR(25)  /* Watchdog Timeout Interrupt */
+
+#define EE_READY_vect_num   26
 #define EE_READY_vect       _VECTOR(26)  /* EEPROM Ready */
+
+#define TIMER0_COMPB_vect_num 27
 #define TIMER0_COMPB_vect   _VECTOR(27)  /* Timer Counter 0 Compare Match B */
+
+#define INT3_vect_num       28
 #define INT3_vect           _VECTOR(28)  /* External Interrupt Request 3 */
+
 /* Vector 29, Reserved */
+
 /* Vector 30, Reserved */
+
+#define SPM_READY_vect_num  31
 #define SPM_READY_vect      _VECTOR(31)  /* Store Program Memory Read */
 
 #define _VECTORS_SIZE 64
@@ -1149,11 +1387,13 @@
 
 
 /* Memory Sizes */
-#define RAMEND         0x1FF
-#define XRAMEND        0x00
+#define RAMEND         0x2FF
+#define XRAMSIZE       0
+#define XRAMEND        RAMEND
 #define E2END          0x1FF
+#define E2PAGESIZE     4
 #define FLASHEND       0x1FFF
-#define SPM_PAGESIZE   32
+#define SPM_PAGESIZE   64
 
 
 
@@ -1162,38 +1402,50 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0  ~_BV(0)  /* Select Clock Source */
-#define CKSEL1  ~_BV(1)  /* Select Clock Source */
-#define CKSEL2  ~_BV(2)  /* Select Clock Source */
-#define CKSEL3  ~_BV(3)  /* Select Clock Source */
-#define SUT0    ~_BV(4)  /* Select start-up time */
-#define SUT1    ~_BV(5)  /* Select start-up time */
-#define CKOUT   ~_BV(6) /* Oscillator output option */
-#define CLKDIV8 ~_BV(7)  /* Divide clock by 8 */
-#define LFUSE_DEFAULT (CKSEL1 & CKSEL2 & CKSEL3 & SUT0 & SUT1 & CKDIV8)
+#define FUSE_CKSEL0  (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1  (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2  (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3  (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0    (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1    (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT   (unsigned char)~_BV(6)  /* Oscillator output option */
+#define FUSE_CKDIV8  (unsigned char)~_BV(7)  /* Divide clock by 8 */
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 
 /* High Fuse Byte */
-#define BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
-#define BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
-#define BODLEVEL2 ~_BV(2)  /* Brown out detector trigger level */
-#define EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define WDTON     ~_BV(4)  /* Watchdog timer always on */
-#define SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define RSTDISBL  ~_BV(7)  /* External Reset Disable */
-#define HFUSE_DEFAULT (SPIEN)    
+#define FUSE_BODLEVEL0 (unsigned char)~_BV(0)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1 (unsigned char)~_BV(1)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2 (unsigned char)~_BV(2)  /* Brown out detector trigger level */
+#define FUSE_EESAVE    (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     (unsigned char)~_BV(4)  /* Watchdog timer always on */
+#define FUSE_SPIEN     (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      (unsigned char)~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  (unsigned char)~_BV(7)  /* External Reset Disable */
+#define HFUSE_DEFAULT (FUSE_SPIEN)    
 
 
 /* Extended Fuse Byte */
-#define BOOTRST ~_BV(0)  /* Select Reset Vector */
-#define BOOTSZ0 ~_BV(1)  /* Select Boot Size */
-#define BOOTSZ1 ~_BV(2)  /* Select Boot Size */
-#define PSCRV   ~_BV(4)  /* PSCOUT Reset Value */
-#define PSC0RB  ~_BV(5)  /* PSC0 Reset Behaviour */
-#define PSC1RB  ~_BV(6)  /* PSC1 Reset Behaviour */
-#define PSC2RB  ~_BV(7)  /* PSC2 Reset Behaviour */
-#define EFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1)
+#define FUSE_BOOTRST (unsigned char)~_BV(0)  /* Select Reset Vector */
+#define FUSE_BOOTSZ0 (unsigned char)~_BV(1)  /* Select Boot Size */
+#define FUSE_BOOTSZ1 (unsigned char)~_BV(2)  /* Select Boot Size */
+#define FUSE_PSCRV   (unsigned char)~_BV(4)  /* PSCOUT Reset Value */
+#define FUSE_PSC0RB  (unsigned char)~_BV(5)  /* PSC0 Reset Behaviour */
+#define FUSE_PSC1RB  (unsigned char)~_BV(6)  /* PSC1 Reset Behaviour */
+#define FUSE_PSC2RB  (unsigned char)~_BV(7)  /* PSC2 Reset Behaviour */
+#define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
+
+
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x93
+#define SIGNATURE_2 0x83
 
 
 #endif /* _AVR_IO90PWM2B_H_ */
