@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom161.h,v 1.10.2.2 2008/01/06 20:10:43 arcanum Exp $ */
+/* $Id: iom161.h 2229 2011-03-05 17:00:18Z arcanum $ */
 
 /* avr/iom161.h - definitions for ATmega161 */
 
@@ -228,82 +228,102 @@
 /* Interrupt vectors */
 
 /* External Interrupt 0 */
-#define INT0_vect			_VECTOR(1)
+#define INT0_vect_num			1
+#define INT0_vect				_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt 1 */
-#define INT1_vect			_VECTOR(2)
+#define INT1_vect_num			2
+#define INT1_vect				_VECTOR(2)
 #define SIG_INTERRUPT1			_VECTOR(2)
 
 /* External Interrupt 2 */
-#define INT2_vect			_VECTOR(3)
+#define INT2_vect_num			3
+#define INT2_vect				_VECTOR(3)
 #define SIG_INTERRUPT2			_VECTOR(3)
 
 /* Timer/Counter2 Compare Match */
+#define TIMER2_COMP_vect_num	4
 #define TIMER2_COMP_vect		_VECTOR(4)
 #define SIG_OUTPUT_COMPARE2		_VECTOR(4)
 
 /* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect_num		5
 #define TIMER2_OVF_vect			_VECTOR(5)
 #define SIG_OVERFLOW2			_VECTOR(5)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	6
 #define TIMER1_CAPT_vect		_VECTOR(6)
 #define SIG_INPUT_CAPTURE1		_VECTOR(6)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num	7
 #define TIMER1_COMPA_vect		_VECTOR(7)
-#define SIG_OUTPUT_COMPARE1A		_VECTOR(7)
+#define SIG_OUTPUT_COMPARE1A	_VECTOR(7)
 
 /* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect_num	8
 #define TIMER1_COMPB_vect		_VECTOR(8)
-#define SIG_OUTPUT_COMPARE1B		_VECTOR(8)
+#define SIG_OUTPUT_COMPARE1B	_VECTOR(8)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		9
 #define TIMER1_OVF_vect			_VECTOR(9)
 #define SIG_OVERFLOW1			_VECTOR(9)
 
 /* Timer/Counter0 Compare Match */
+#define TIMER0_COMP_vect_num	10
 #define TIMER0_COMP_vect		_VECTOR(10)
 #define SIG_OUTPUT_COMPARE0		_VECTOR(10)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		11
 #define TIMER0_OVF_vect			_VECTOR(11)
 #define SIG_OVERFLOW0			_VECTOR(11)
 
 /* Serial Transfer Complete */
+#define SPI_STC_vect_num		12
 #define SPI_STC_vect			_VECTOR(12)
-#define SIG_SPI				_VECTOR(12)
+#define SIG_SPI				    _VECTOR(12)
 
 /* UART0, Rx Complete */
+#define UART0_RX_vect_num		13
 #define UART0_RX_vect			_VECTOR(13)
 #define SIG_UART0_RECV			_VECTOR(13)
 
 /* UART1, Rx Complete */
+#define UART1_RX_vect_num		14
 #define UART1_RX_vect			_VECTOR(14)
 #define SIG_UART1_RECV			_VECTOR(14)
 
 /* UART0 Data Register Empty */
+#define UART0_UDRE_vect_num		15
 #define UART0_UDRE_vect			_VECTOR(15)
 #define SIG_UART0_DATA			_VECTOR(15)
 
 /* UART1 Data Register Empty */
+#define UART1_UDRE_vect_num		16
 #define UART1_UDRE_vect			_VECTOR(16)
 #define SIG_UART1_DATA			_VECTOR(16)
 
 /* UART0, Tx Complete */
+#define UART0_TX_vect_num		17
 #define UART0_TX_vect			_VECTOR(17)
 #define SIG_UART0_TRANS			_VECTOR(17)
 
 /* UART1, Tx Complete */
+#define UART1_TX_vect_num		18
 #define UART1_TX_vect			_VECTOR(18)
 #define SIG_UART1_TRANS			_VECTOR(18)
 
 /* EEPROM Ready */
-#define EE_RDY_vect			_VECTOR(19)
+#define EE_RDY_vect_num			19
+#define EE_RDY_vect			    _VECTOR(19)
 #define SIG_EEPROM_READY		_VECTOR(19)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		20
 #define ANA_COMP_vect			_VECTOR(20)
 #define SIG_COMPARATOR			_VECTOR(20)
 
@@ -640,6 +660,7 @@
 #define RAMEND		0x45F
 #define XRAMEND		0xFFFF
 #define E2END		0x1FF
+#define E2PAGESIZE  0
 #define FLASHEND	0x3FFF
 
 
@@ -648,12 +669,12 @@
 #define FUSE_MEMORY_SIZE 1
 
 /* Fuse Byte */
-#define FUSE_CKSEL0      ~_BV(0)
-#define FUSE_CKSEL1      ~_BV(1)
-#define FUSE_CKSEL2      ~_BV(2)
-#define FUSE_SUT         ~_BV(4)
-#define FUSE_SPIEN       ~_BV(5)
-#define FUSE_BOOTRST     ~_BV(6)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_SUT         (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_BOOTRST     (unsigned char)~_BV(6)
 #define FUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_SPIEN)
 
 
@@ -663,4 +684,39 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x94
+#define SIGNATURE_2 0x01
+
+
+/* Deprecated items */
+#if !defined(__AVR_LIBC_DEPRECATED_ENABLE__)
+
+#pragma GCC system_header
+
+#pragma GCC poison SIG_INTERRUPT0
+#pragma GCC poison SIG_INTERRUPT1
+#pragma GCC poison SIG_INTERRUPT2
+#pragma GCC poison SIG_OUTPUT_COMPARE2
+#pragma GCC poison SIG_OVERFLOW2
+#pragma GCC poison SIG_INPUT_CAPTURE1
+#pragma GCC poison SIG_OUTPUT_COMPARE1A
+#pragma GCC poison SIG_OUTPUT_COMPARE1B
+#pragma GCC poison SIG_OVERFLOW1
+#pragma GCC poison SIG_OUTPUT_COMPARE0
+#pragma GCC poison SIG_OVERFLOW0
+#pragma GCC poison SIG_SPI
+#pragma GCC poison SIG_UART0_RECV
+#pragma GCC poison SIG_UART1_RECV
+#pragma GCC poison SIG_UART0_DATA
+#pragma GCC poison SIG_UART1_DATA
+#pragma GCC poison SIG_UART0_TRANS
+#pragma GCC poison SIG_UART1_TRANS
+#pragma GCC poison SIG_EEPROM_READY
+#pragma GCC poison SIG_COMPARATOR
+
+#endif  /* !defined(__AVR_LIBC_DEPRECATED_ENABLE__) */
+
+
 #endif /* _AVR_IOM161_H_ */
