@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom32m1.h,v 1.1.2.9 2009/08/07 01:25:49 arcanum Exp $ */
+/* $Id: iom32m1.h 2235 2011-03-17 04:13:14Z arcanum $ */
 
 /* avr/iom32m1.h - definitions for ATmega32M1 */
 
@@ -1180,6 +1180,9 @@
 
 #define CANIE1 _SFR_MEM8(0xDF)
 
+/* RegDef:  CAN Status Interrupt MOb Register*/
+#define CANSIT _SFR_MEM16(0xE0)
+
 #define CANSIT2 _SFR_MEM8(0xE0)
 #define SIT0 0
 #define SIT1 1
@@ -1328,6 +1331,9 @@
 #define CONMOB0 6
 #define CONMOB1 7
 
+/* RegDef:  CAN Identifier Tag Registers*/
+#define CANIDT  _SFR_MEM32(0xF0)
+
 #define CANIDT4 _SFR_MEM8(0xF0)
 #define RB0TAG 0
 #define RB1TAG 1
@@ -1368,6 +1374,9 @@
 #define IDT27 6
 #define IDT28 7
 
+/* RegDef:  CAN Identifier Mask Registers */
+#define CANIDM  _SFR_MEM32(0xF4)
+
 #define CANIDM4 _SFR_MEM8(0xF4)
 #define IDEMSK 0
 #define RTRMSK 2
@@ -1567,5 +1576,36 @@
 #define SIGNATURE_2 0x84
 
 
+/* Deprecated items */
+#if !defined(__AVR_LIBC_DEPRECATED_ENABLE__)
+
+#pragma GCC system_header
+
+#pragma GCC poison POCR0SA_00
+#pragma GCC poison POCR0SA_01
+#pragma GCC poison POCR0RA_00
+#pragma GCC poison POCR0RA_01
+#pragma GCC poison POCR0SB_00
+#pragma GCC poison POCR0SB_01
+#pragma GCC poison POCR1SA_00
+#pragma GCC poison POCR1SA_01
+#pragma GCC poison POCR1RA_00
+#pragma GCC poison POCR1SB_00
+#pragma GCC poison POCR1SB_01
+#pragma GCC poison POCR2SA_00
+#pragma GCC poison POCR2SA_01
+#pragma GCC poison POCR2RA_00
+#pragma GCC poison POCR2RA_01
+#pragma GCC poison POCR2SB_00
+#pragma GCC poison POCR2SB_01
+#pragma GCC poison POCRxRB
+#pragma GCC poison POCRxRBL
+#pragma GCC poison POCRxRBH
+#pragma GCC poison POCR_RB_00
+#pragma GCC poison POCR_RB_01
+
+#endif  /* !defined(__AVR_LIBC_DEPRECATED_ENABLE__) */
+
+
 #endif /* _AVR_ATmega32M1_H_ */
 
