@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom8u2.h,v 1.1.2.2 2009/07/17 17:09:31 arcanum Exp $ */
+/* $Id: iom8u2.h 2245 2011-05-12 22:42:21Z arcanum $ */
 
 /* avr/iom8u2.h - definitions for ATmega8U2 */
 
@@ -840,6 +840,16 @@
 #define EPINT3 3
 #define EPINT4 4
 
+#define UPOE    _SFR_MEM8(0XFB)
+#define UPWE1   7
+#define UPWE0   6
+#define UPDRV1  5
+#define UPDRV0  4
+#define SCKI    3
+#define DATAI   2
+#define DPI     1
+#define DMI     0
+
 
 /* Interrupt vectors */
 /* Vector 0 is the reset vector */
@@ -901,7 +911,7 @@
 #define TIMER1_OVF_vect      _VECTOR(18)  /* Timer/Counter1 Overflow */
 
 #define _VECTOR_SIZE 4 /* Size of individual vector. */
-#define _VECTORS_SIZE (38 * _VECTOR_SIZE)
+#define _VECTORS_SIZE (29 * _VECTOR_SIZE)
 
 
 /* Constants */
