@@ -30,7 +30,7 @@
 
 /* avr/iomXX4.h - definitions for ATmega164P/324P/644P and ATmega644 */
 
-/* $Id: iomxx4.h,v 1.9.2.4 2007/02/24 14:03:25 aesok Exp $ */
+/* $Id: iomxx4.h 2235 2011-03-17 04:13:14Z arcanum $ */
 
 #ifndef _AVR_IOMXX4_H_
 #define _AVR_IOMXX4_H_ 1
@@ -322,6 +322,10 @@
 
 #define MCUCR	_SFR_IO8(0X35)
 #define JTD	7
+#if !defined(__AVR_ATmega644__)
+#define BODS    6
+#define BODSE   5
+#endif
 #define PUD	4
 #define IVSEL	1
 #define IVCE	0
@@ -663,6 +667,7 @@
 #define USBS0	3
 #define UCSZ01	2
 #define UCSZ00	1
+#define UCPHA0  1
 #define UCPOL0	0
 
 /* Reserved [0xC3] */
@@ -709,6 +714,7 @@
 #define USBS1	3
 #define UCSZ11	2
 #define UCSZ10	1
+#define UCPHA1  1
 #define UCPOL1	0
 
 /* Reserved [0xCB] */
@@ -727,110 +733,137 @@
 /* Interrupt vectors */
 /* Vector 0 is the reset vector */
 /* External Interrupt Request 0 */
-#define INT0_vect			_VECTOR(1)
+#define INT0_vect_num			1
+#define INT0_vect			    _VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt Request 1 */
-#define INT1_vect			_VECTOR(2)
+#define INT1_vect_num			2
+#define INT1_vect			    _VECTOR(2)
 #define SIG_INTERRUPT1			_VECTOR(2)
 
 /* External Interrupt Request 2 */
-#define INT2_vect			_VECTOR(3)
+#define INT2_vect_num			3
+#define INT2_vect	    		_VECTOR(3)
 #define SIG_INTERRUPT2			_VECTOR(3)
 
 /* Pin Change Interrupt Request 0 */
-#define PCINT0_vect			_VECTOR(4)
+#define PCINT0_vect_num			4
+#define PCINT0_vect			    _VECTOR(4)
 #define SIG_PIN_CHANGE0			_VECTOR(4)
 
 /* Pin Change Interrupt Request 1 */
-#define PCINT1_vect			_VECTOR(5)
+#define PCINT1_vect_num			5
+#define PCINT1_vect		    	_VECTOR(5)
 #define SIG_PIN_CHANGE1			_VECTOR(5)
 
 /* Pin Change Interrupt Request 2 */
-#define PCINT2_vect			_VECTOR(6)
+#define PCINT2_vect_num  		6
+#define PCINT2_vect				_VECTOR(6)
 #define SIG_PIN_CHANGE2			_VECTOR(6)
 
 /* Pin Change Interrupt Request 3 */
-#define PCINT3_vect			_VECTOR(7)
+#define PCINT3_vect_num			7
+#define PCINT3_vect			    _VECTOR(7)
 #define SIG_PIN_CHANGE3			_VECTOR(7)
 
 /* Watchdog Time-out Interrupt */
-#define WDT_vect			_VECTOR(8)
-#define SIG_WATCHDOG_TIMEOUT		_VECTOR(8)
+#define WDT_vect_num			8
+#define WDT_vect		    	_VECTOR(8)
+#define SIG_WATCHDOG_TIMEOUT	_VECTOR(8)
 
 /* Timer/Counter2 Compare Match A */
+#define TIMER2_COMPA_vect_num	9
 #define TIMER2_COMPA_vect		_VECTOR(9)
-#define SIG_OUTPUT_COMPARE2A		_VECTOR(9)
+#define SIG_OUTPUT_COMPARE2A	_VECTOR(9)
 
 /* Timer/Counter2 Compare Match B */
+#define TIMER2_COMPB_vect_num	10
 #define TIMER2_COMPB_vect		_VECTOR(10)
-#define SIG_OUTPUT_COMPARE2B		_VECTOR(10)
+#define SIG_OUTPUT_COMPARE2B	_VECTOR(10)
 
 /* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect_num		11
 #define TIMER2_OVF_vect			_VECTOR(11)
 #define SIG_OVERFLOW2			_VECTOR(11)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	12
 #define TIMER1_CAPT_vect		_VECTOR(12)
 #define SIG_INPUT_CAPTURE1		_VECTOR(12)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num	13
 #define TIMER1_COMPA_vect		_VECTOR(13)
-#define SIG_OUTPUT_COMPARE1A		_VECTOR(13)
+#define SIG_OUTPUT_COMPARE1A	_VECTOR(13)
 
 /* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect_num	14
 #define TIMER1_COMPB_vect		_VECTOR(14)
-#define SIG_OUTPUT_COMPARE1B		_VECTOR(14)
+#define SIG_OUTPUT_COMPARE1B	_VECTOR(14)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		15
 #define TIMER1_OVF_vect			_VECTOR(15)
 #define SIG_OVERFLOW1			_VECTOR(15)
 
 /* Timer/Counter0 Compare Match A */
+#define TIMER0_COMPA_vect_num	16
 #define TIMER0_COMPA_vect		_VECTOR(16)
-#define SIG_OUTPUT_COMPARE0A		_VECTOR(16)
+#define SIG_OUTPUT_COMPARE0A	_VECTOR(16)
 
 /* Timer/Counter0 Compare Match B */
+#define TIMER0_COMPB_vect_num	17
 #define TIMER0_COMPB_vect		_VECTOR(17)
-#define SIG_OUTPUT_COMPARE0B		_VECTOR(17)
+#define SIG_OUTPUT_COMPARE0B	_VECTOR(17)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		18
 #define TIMER0_OVF_vect			_VECTOR(18)
 #define SIG_OVERFLOW0			_VECTOR(18)
 
 /* SPI Serial Transfer Complete */
+#define SPI_STC_vect_num		19
 #define SPI_STC_vect			_VECTOR(19)
-#define SIG_SPI				_VECTOR(19)
+#define SIG_SPI				    _VECTOR(19)
 
 /* USART0, Rx Complete */
+#define USART0_RX_vect_num		20
 #define USART0_RX_vect			_VECTOR(20)
 #define SIG_USART_RECV			_VECTOR(20)
 
 /* USART0 Data register Empty */
+#define USART0_UDRE_vect_num	21
 #define USART0_UDRE_vect		_VECTOR(21)
 #define SIG_USART_DATA			_VECTOR(21)
 
 /* USART0, Tx Complete */
+#define USART0_TX_vect_num		22
 #define USART0_TX_vect			_VECTOR(22)
 #define SIG_USART_TRANS			_VECTOR(22)
 
 /* Analog Comparator */
+#define ANALOG_COMP_vect_num	23
 #define ANALOG_COMP_vect		_VECTOR(23)
 #define SIG_COMPARATOR			_VECTOR(23)
 
 /* ADC Conversion Complete */
-#define ADC_vect			_VECTOR(24)
-#define SIG_ADC				_VECTOR(24)
+#define ADC_vect_num			24
+#define ADC_vect	    		_VECTOR(24)
+#define SIG_ADC			    	_VECTOR(24)
 
 /* EEPROM Ready */
+#define EE_READY_vect_num		25
 #define EE_READY_vect			_VECTOR(25)
 #define SIG_EEPROM_READY		_VECTOR(25)
 
 /* 2-wire Serial Interface */
-#define TWI_vect			_VECTOR(26)
+#define TWI_vect_num			26
+#define TWI_vect	    		_VECTOR(26)
 #define SIG_2WIRE_SERIAL		_VECTOR(26)
 
 /* Store Program Memory Read */
+#define SPM_READY_vect_num		27
 #define SPM_READY_vect			_VECTOR(27)
 #define SIG_SPM_READY			_VECTOR(27)
 
@@ -842,16 +875,19 @@
 
 /* USART1, Rx Complete */
 /* USART1 RX complete */
+#define USART1_RX_vect_num		28
 #define USART1_RX_vect			_VECTOR(28)
 #define SIG_USART1_RECV			_VECTOR(28)
 
 /* USART1 Data register Empty */
 /* USART1 Data Register Empty */
+#define USART1_UDRE_vect_num	29
 #define USART1_UDRE_vect		_VECTOR(29)
 #define SIG_USART1_DATA			_VECTOR(29)
 
 /* USART1, Tx Complete */
 /* USART1 TX complete */
+#define USART1_TX_vect_num		30
 #define USART1_TX_vect			_VECTOR(30)
 #define SIG_USART1_TRANS		_VECTOR(30)
 
@@ -860,4 +896,43 @@
 #endif /* defined(__AVR_ATmega644__) */
 
 
+/* Deprecated items */
+#if !defined(__AVR_LIBC_DEPRECATED_ENABLE__)
+
+#pragma GCC system_header
+
+#pragma GCC poison SIG_INTERRUPT0
+#pragma GCC poison SIG_INTERRUPT1
+#pragma GCC poison SIG_INTERRUPT2
+#pragma GCC poison SIG_PIN_CHANGE0
+#pragma GCC poison SIG_PIN_CHANGE1
+#pragma GCC poison SIG_PIN_CHANGE2
+#pragma GCC poison SIG_PIN_CHANGE3
+#pragma GCC poison SIG_WATCHDOG_TIMEOUT
+#pragma GCC poison SIG_OUTPUT_COMPARE2A
+#pragma GCC poison SIG_OUTPUT_COMPARE2B
+#pragma GCC poison SIG_OVERFLOW2
+#pragma GCC poison SIG_INPUT_CAPTURE1
+#pragma GCC poison SIG_OUTPUT_COMPARE1A
+#pragma GCC poison SIG_OUTPUT_COMPARE1B
+#pragma GCC poison SIG_OVERFLOW1
+#pragma GCC poison SIG_OUTPUT_COMPARE0A
+#pragma GCC poison SIG_OUTPUT_COMPARE0B
+#pragma GCC poison SIG_OVERFLOW0
+#pragma GCC poison SIG_SPI
+#pragma GCC poison SIG_USART_RECV
+#pragma GCC poison SIG_USART_DATA
+#pragma GCC poison SIG_USART_TRANS
+#pragma GCC poison SIG_COMPARATOR
+#pragma GCC poison SIG_ADC
+#pragma GCC poison SIG_EEPROM_READY
+#pragma GCC poison SIG_2WIRE_SERIAL
+#pragma GCC poison SIG_SPM_READY
+#pragma GCC poison SIG_USART1_RECV
+#pragma GCC poison SIG_USART1_DATA
+#pragma GCC poison SIG_USART1_TRANS
+
+#endif  /* !defined(__AVR_LIBC_DEPRECATED_ENABLE__) */
+
+
 #endif /* _AVR_IOMXX4_H_ */
