@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotnx4.h,v 1.1.2.4 2007/05/14 22:33:27 joerg_wunsch Exp $ */
+/* $Id: iotnx4.h 2225 2011-03-02 16:27:26Z arcanum $ */
 
 /* avr/iotnx4.h - definitions for ATtiny24, ATtiny44 and ATtiny84 */
 
@@ -335,16 +335,19 @@
 #define PORF    0
 
 #define MCUCR   _SFR_IO8(0x35)
+#define BODS    7
 #define PUD     6
 #define SE      5
 #define SM1     4
 #define SM0     3
+#define BODSE   2
 #define ISC01   1
 #define ISC00   0
 
 #define OCR0A   _SFR_IO8(0x36)
 
 #define SPMCSR  _SFR_IO8(0x37)
+#define RSIG    5
 #define CTPB    4
 #define RFLB    3
 #define PGWRT   2
@@ -381,70 +384,90 @@
 /* Interrupt vectors */
 /* Interrupt vector 0 is the reset vector. */
 /* External Interrupt Request 0 */
-#define INT0_vect			_VECTOR(1)
+#define INT0_vect_num		    1
+#define INT0_vect			    _VECTOR(1)
+#define EXT_INT0_vect_num    	1
 #define EXT_INT0_vect			_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* Pin Change Interrupt Request 0 */
-#define PCINT0_vect			_VECTOR(2)
+#define PCINT0_vect_num		    2
+#define PCINT0_vect			    _VECTOR(2)
 #define SIG_PIN_CHANGE0			_VECTOR(2)
 
 /* Pin Change Interrupt Request 1 */
-#define PCINT1_vect			_VECTOR(3)
+#define PCINT1_vect_num		    3
+#define PCINT1_vect			    _VECTOR(3)
 #define SIG_PIN_CHANGE1			_VECTOR(3)
 
 /* Watchdog Time-out */
-#define WDT_vect			_VECTOR(4)
+#define WDT_vect_num			4
+#define WDT_vect			    _VECTOR(4)
+#define WATCHDOG_vect_num		4
 #define WATCHDOG_vect			_VECTOR(4)
-#define SIG_WATCHDOG_TIMEOUT		_VECTOR(4)
+#define SIG_WATCHDOG_TIMEOUT	_VECTOR(4)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	5
 #define TIMER1_CAPT_vect		_VECTOR(5)
+#define TIM1_CAPT_vect_num		5
 #define TIM1_CAPT_vect			_VECTOR(5)
 #define SIG_INPUT_CAPTURE1		_VECTOR(5)
 
 /* Timer/Counter1 Compare Match A */
+#define TIM1_COMPA_vect_num		6
 #define TIM1_COMPA_vect			_VECTOR(6)
-#define SIG_OUTPUT_COMPARE1A		_VECTOR(6)
+#define SIG_OUTPUT_COMPARE1A	_VECTOR(6)
 
 /* Timer/Counter1 Compare Match B */
+#define TIM1_COMPB_vect_num		7
 #define TIM1_COMPB_vect			_VECTOR(7)
-#define SIG_OUTPUT_COMPARE1B		_VECTOR(7)
+#define SIG_OUTPUT_COMPARE1B	_VECTOR(7)
 
 /* Timer/Counter1 Overflow */
+#define TIM1_OVF_vect_num		8
 #define TIM1_OVF_vect			_VECTOR(8)
 #define SIG_OVERFLOW1			_VECTOR(8)
 
 /* Timer/Counter0 Compare Match A */
+#define TIM0_COMPA_vect_num		9
 #define TIM0_COMPA_vect			_VECTOR(9)
-#define SIG_OUTPUT_COMPARE0A		_VECTOR(9)
+#define SIG_OUTPUT_COMPARE0A	_VECTOR(9)
 
 /* Timer/Counter0 Compare Match B */
+#define TIM0_COMPB_vect_num		10
 #define TIM0_COMPB_vect			_VECTOR(10)
-#define SIG_OUTPUT_COMPARE0B		_VECTOR(10)
+#define SIG_OUTPUT_COMPARE0B	_VECTOR(10)
 
 /* Timer/Counter0 Overflow */
+#define TIM0_OVF_vect_num		11
 #define TIM0_OVF_vect			_VECTOR(11)
 #define SIG_OVERFLOW0			_VECTOR(11)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		12
 #define ANA_COMP_vect			_VECTOR(12)
 #define SIG_COMPARATOR			_VECTOR(12)
 
 /* ADC Conversion Complete */
-#define ADC_vect			_VECTOR(13)
-#define SIG_ADC				_VECTOR(13)
+#define ADC_vect_num		    13
+#define ADC_vect			    _VECTOR(13)
+#define SIG_ADC				    _VECTOR(13)
 
 /* EEPROM Ready */
-#define EE_RDY_vect			_VECTOR(14)
+#define EE_RDY_vect_num		    14
+#define EE_RDY_vect			    _VECTOR(14)
 #define SIG_EEPROM_READY		_VECTOR(14)
 
 /* USI START */
+#define USI_START_vect_num		15
 #define USI_START_vect			_VECTOR(15)
+#define USI_STR_vect_num		15
 #define USI_STR_vect			_VECTOR(15)
 #define SIG_USI_START			_VECTOR(15)
 
 /* USI Overflow */
+#define USI_OVF_vect_num		16
 #define USI_OVF_vect			_VECTOR(16)
 #define SIG_USI_OVERFLOW		_VECTOR(16)
 
