@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: inttypes.h,v 1.16 2007/01/23 15:32:48 joerg_wunsch Exp $ */
+/* $Id: inttypes.h 1766 2008-10-17 21:33:57Z arcanum $ */
 
 #ifndef __INTTYPES_H_
 #define __INTTYPES_H_
@@ -63,8 +63,8 @@
     uint8_t smallval;
     int32_t longval;
     ...
-    printf("The hexadecimal value of smallval is " PRIx8
-           ", the decimal value of longval is " PRId32 ".\n",
+    printf("The hexadecimal value of smallval is %" PRIx8
+           ", the decimal value of longval is %" PRId32 ".\n",
 	   smallval, longval);
     \endcode
 */
