@@ -27,7 +27,9 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: puts_p.c,v 1.5.4.1 2009/04/01 23:12:00 arcanum Exp $ */
+/* $Id: puts_p.c 2191 2010-11-05 13:45:57Z arcanum $ */
+
+#if !defined(__AVR_TINY__)
 
 #include <stdio.h>
 #include <avr/pgmspace.h>
@@ -58,3 +60,5 @@ puts_P(const char *str)
 
 	return rv;
 }
+
+#endif /* !defined(__AVR_TINY__) */
