@@ -30,7 +30,9 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: vfscanf.c,v 1.13.4.2 2009/04/01 23:12:06 arcanum Exp $ */
+/* $Id: vfscanf.c 2191 2010-11-05 13:45:57Z arcanum $ */
+
+#if !defined(__AVR_TINY__)
 
 #include <avr/pgmspace.h>
 #include <ctype.h>
@@ -880,3 +882,5 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
   eof:
     return nconvs ? nconvs : EOF;
 }
+
+#endif /* !defined(__AVR_TINY__) */
